# SQL script to create a database for the mailadm program
# The database is table and field compatible with the 
# suggested courier mysql setup.
#
# NOTE: ALL DATA IN ANY EXISTING MAILDATABASE WITH
#	THE SAME NAME WILL BE LOST! Back up the data
#	and insert them back into the new table
#	if you have a working mysql database for 
#	the courier maiolserver!


DROP TABLE IF EXISTS passwd;
CREATE TABLE passwd (
    passwd_id             int NOT NULL auto_increment,                  # Unique reference
    id                    char(128) DEFAULT '' NOT NULL,
    crypt                 char(128) DEFAULT '' NOT NULL,
    clear                 char(128) DEFAULT '' NOT NULL,
    name                  char(128) DEFAULT '' NOT NULL,
    uid                   int(10) unsigned DEFAULT '65534' NOT NULL,
    gid                   int(10) unsigned DEFAULT '65534' NOT NULL,
    home                  char(255) DEFAULT '' NOT NULL,
    maildir               char(255) DEFAULT '' NOT NULL,
    quota                 char(255) DEFAULT '' NOT NULL,
    organization_id       int DEFAULT '0' NOT NULL,                     # Link to organization.organization_id
    active                enum('yes', 'no') DEFAULT 'yes' NOT NULL,     # Active
    old_popname		  varchar(50) DEFAULT '' NOT NULL,		# Use to migrate old pop3-clients to courier

    PRIMARY KEY(passwd_id),
    UNIQUE key_id (id(128)),
    KEY org_key(organization_id)
);

DROP TABLE IF EXISTS alias;
CREATE TABLE alias (
    alias_id             int NOT NULL auto_increment,                   # Unique reference
    mailaddr             char(128) NOT NULL,                            # From mail address
    passwd_id            int NOT NULL,                                  # Link to passwd.passwd_id
    organization_id      int NOT NULL,					# Link to organization.organization_id

    PRIMARY KEY(alias_id),
    UNIQUE mailaddr_key(mailaddr(128)),
    KEY passwd_key(passwd_id),
    KEY org_key(organization_id)
);

DROP TABLE IF EXISTS organization;
CREATE TABLE organization (                                             # Unique reference
    organization_id     int NOT NULL auto_increment,
    name                varchar(50) NOT NULL,
    default_domain      varchar(50) NOT NULL,				# domain name for this organization
    inbound_mailserver  varchar(128) NOT NULL,				# pop3/imap server
    outbound_mailserver varchar(128) NOT NULL,				# smtp/esmtp server
    hosted_here         enum('yes', 'no') DEFAULT 'yes' NOT NULL,	# if not local we just store names and passwords

    KEY(organization_id),
    UNIQUE name_key(name(50))
);

